@@ -5,7 +5,7 @@ use Moo::Role;
 use Log::Any qw/$log/;
 use Carp qw/croak carp confess/;
 
-our $VERSION = '0.191.0';
+our $VERSION = '0.971.0';
 
 sub sqlite_create_function_debug {
     my $self = shift;
@@ -22,7 +22,8 @@ sub sqlite_create_function_debug {
                 my $sth = $dbh->prepare($sql);
                 $sth->execute(@_);
                 $log->debug(
-                    join( "\n",
+                    $sql . "\n"
+                      . join( "\n",
                         map { DBI::neat_list($_) }
                           @{ $sth->fetchall_arrayref } )
                 );
